@@ -58,9 +58,9 @@ sub options { (
         "m|merge"  => "merge",
         "b|branch" => "branch",
         "verbose"  => "verbose",
-        "ssh"      => "protocal_ssh",    # git@github.com:c9s/repo.git
-        "http"     => "protocal_http",  # http://github.com/c9s/repo.git
-        "https"    => "https",         # https://github.com/c9s/repo.git
+        "ssh"      => "protocol_ssh",    # git@github.com:c9s/repo.git
+        "http"     => "protocol_http",  # http://github.com/c9s/repo.git
+        "https"    => "protocol_https",         # https://github.com/c9s/repo.git
         "git|ro"   => "git"         # git://github.com/c9s/repo.git
     ) }
 
